Crate baraja

Crate baraja 

Structs

Card
CardBitSet
This struct is a bitset for cards Each card is represented by a bit in a 64 bit integer
CardBitSetIter
The iterator for the CardBitSet It iterates over the cards in the bitset
Deck
FlatDeck
FlatDeck is a deck of cards that allows easy indexing into the cards. It does not provide contains methods.
Hand

Enums

Suit
Value
Card rank or value. This is basically the face value - 2