Structs
- Card
- Card
BitSet - This struct is a bitset for cards Each card is represented by a bit in a 64 bit integer
- Card
BitSet Iter - The iterator for the CardBitSet It iterates over the cards in the bitset
- Deck
- Flat
Deck FlatDeckis a deck of cards that allows easy indexing into the cards. It does not provide contains methods.- Hand